@@ -138,6 +138,13 @@ class Service:
         return await self.requests.get_zone_travel_time(fromdatetime, todatetime, period,
                                                         sampling, frompointeid, topointeid)
 
+    @staticmethod
+    async def _get_not_empty(get_coro):
+        res = {}
+        while len(res) == 0:
+            res = await get_coro
+        return res
+
 
 def start(Application, threaded=False):
     if threaded:
